@@ -10,22 +10,36 @@ config() {
   fi
   # Otherwise, we leave the .new copy for the admin to consider...
 }
-config usr/share/ghostscript/8.71/Resource/Init/cidfmap.new
+config usr/share/ghostscript/9.07/Resource/Init/cidfmap.new
+( cd usr/doc/ghostscript-9.07 ; rm -rf doc )
+( cd usr/doc/ghostscript-9.07 ; ln -sf /usr/share/ghostscript/9.07/doc doc )
+( cd usr/lib/cups/filter ; rm -rf pstoraster )
+( cd usr/lib/cups/filter ; ln -sf gstoraster pstoraster )
+( cd usr/lib ; rm -rf libgs.so.9 )
+( cd usr/lib ; ln -sf libgs.so.9.07 libgs.so.9 )
 ( cd usr/lib ; rm -rf libgs.so )
-( cd usr/lib ; ln -sf libgs.so.8.71 libgs.so )
-( cd usr/lib ; rm -rf libgs.so.8 )
-( cd usr/lib ; ln -sf libgs.so.8.71 libgs.so.8 )
-( cd usr/doc/ghostscript-8.71 ; rm -rf doc )
-( cd usr/doc/ghostscript-8.71 ; ln -sf /usr/share/ghostscript/8.71/doc doc )
-( cd usr/man/man1 ; rm -rf ps2pdf12.1.gz )
-( cd usr/man/man1 ; ln -sf ps2pdf.1.gz ps2pdf12.1.gz )
-( cd usr/man/man1 ; rm -rf eps2eps.1.gz )
-( cd usr/man/man1 ; ln -sf ps2ps.1.gz eps2eps.1.gz )
-( cd usr/man/man1 ; rm -rf ps2pdf13.1.gz )
-( cd usr/man/man1 ; ln -sf ps2pdf.1.gz ps2pdf13.1.gz )
-( cd usr/man/de/man1 ; rm -rf ps2pdf12.1.gz )
-( cd usr/man/de/man1 ; ln -sf ps2pdf.1.gz ps2pdf12.1.gz )
+( cd usr/lib ; ln -sf libgs.so.9.07 libgs.so )
+( cd usr/man/de/man1 ; rm -rf ps2pdf14.1.gz )
+( cd usr/man/de/man1 ; ln -sf ps2pdf.1.gz ps2pdf14.1.gz )
 ( cd usr/man/de/man1 ; rm -rf eps2eps.1.gz )
 ( cd usr/man/de/man1 ; ln -sf ps2ps.1.gz eps2eps.1.gz )
+( cd usr/man/de/man1 ; rm -rf ps2pdf12.1.gz )
+( cd usr/man/de/man1 ; ln -sf ps2pdf.1.gz ps2pdf12.1.gz )
 ( cd usr/man/de/man1 ; rm -rf ps2pdf13.1.gz )
 ( cd usr/man/de/man1 ; ln -sf ps2pdf.1.gz ps2pdf13.1.gz )
+( cd usr/man/man1 ; rm -rf ps2pdf14.1.gz )
+( cd usr/man/man1 ; ln -sf ps2pdf.1.gz ps2pdf14.1.gz )
+( cd usr/man/man1 ; rm -rf gsbj.1.gz )
+( cd usr/man/man1 ; ln -sf gslp.1.gz gsbj.1.gz )
+( cd usr/man/man1 ; rm -rf gslj.1.gz )
+( cd usr/man/man1 ; ln -sf gslp.1.gz gslj.1.gz )
+( cd usr/man/man1 ; rm -rf eps2eps.1.gz )
+( cd usr/man/man1 ; ln -sf ps2ps.1.gz eps2eps.1.gz )
+( cd usr/man/man1 ; rm -rf gsdj500.1.gz )
+( cd usr/man/man1 ; ln -sf gslp.1.gz gsdj500.1.gz )
+( cd usr/man/man1 ; rm -rf ps2pdf12.1.gz )
+( cd usr/man/man1 ; ln -sf ps2pdf.1.gz ps2pdf12.1.gz )
+( cd usr/man/man1 ; rm -rf gsdj.1.gz )
+( cd usr/man/man1 ; ln -sf gslp.1.gz gsdj.1.gz )
+( cd usr/man/man1 ; rm -rf ps2pdf13.1.gz )
+( cd usr/man/man1 ; ln -sf ps2pdf.1.gz ps2pdf13.1.gz )
